import 'package:flutter/material.dart';
import 'package:sk_base_mobile/app_theme.dart';
import 'package:sk_base_mobile/util/screen_adaper_util.dart';

class SkTextInput extends StatefulWidget {
  final TextEditingController textController;
  final Function(FocusNode)? onTap;
  final bool isRequired;
  final String? labelText;
  final String? hint;
  final bool isTextArea;
  final bool isDense;
  final Function(String)? onTapOutside;
  final Function(String)? onChanged;
  final String? Function(String?)? validator;
  final EdgeInsetsGeometry? contentPadding;
  final bool autoFocus;
  final ValueChanged<String>? onFieldSubmitted;
  final Icon? prefix;
  final Widget? suffixIcon;
  final InputBorder? border;
  final FloatingLabelBehavior? floatingLabelBehavior;
  const SkTextInput(
      {super.key,
      required this.textController,
      this.onTap,
      this.hint,
      this.onFieldSubmitted,
      this.isRequired = false,
      this.onTapOutside,
      this.labelText,
      this.prefix,
      this.suffixIcon,
      this.onChanged,
      this.border,
      this.floatingLabelBehavior = FloatingLabelBehavior.always,
      this.isTextArea = false,
      this.autoFocus = false,
      this.contentPadding,
      this.isDense = false,
      this.validator});

  @override
  State<SkTextInput> createState() => _SkTextInputState();
}

class _SkTextInputState extends State<SkTextInput> {
  late FocusNode focusNode = FocusNode();

  @override
  void initState() {
    super.initState();
    if (widget.autoFocus) {
      WidgetsBinding.instance.addPostFrameCallback((_) {
        focusNode.requestFocus();
      });
    }
  }

  @override
  Widget build(BuildContext context) {
    return TextFormField(
      focusNode: focusNode,
      controller: widget.textController,
      onChanged: (String value) {
        if (widget.onChanged != null) {
          widget.onChanged!(value);
        }
      },
      onTapOutside: (event) {
        if (widget.onTapOutside != null) {
          widget.onTapOutside!(widget.textController.text);
          FocusScope.of(context).unfocus();
        }
      },
      maxLines: widget.isTextArea ? 2 : 1, // 添加这行代码
      onTap: () {
        if (widget.onTap != null) {
          widget.onTap!(focusNode);
        }
      },
      onFieldSubmitted: widget.onFieldSubmitted,
      autovalidateMode: AutovalidateMode.onUserInteraction,
      validator: widget.validator,

      decoration: InputDecoration(
        prefixIcon: widget.prefix,
        suffixIcon: widget.suffixIcon,
        errorStyle: const TextStyle(fontSize: 0, height: 0.01),
        contentPadding: widget.contentPadding,
        isDense: widget.isDense,
        border: widget.border,
        floatingLabelBehavior: widget.floatingLabelBehavior,
        label: widget.labelText != null
            ? Row(
                crossAxisAlignment: CrossAxisAlignment.center,
                mainAxisSize: MainAxisSize.min,
                children: [
                    if (widget.isRequired)
                      Text(
                        "*",
                        style: TextStyle(
                            color: Colors.red,
                            fontSize: ScreenAdaper.height(30)),
                      ),
                    Text(
                      widget.labelText!,
                      style: TextStyle(fontSize: ScreenAdaper.height(30)),
                    ),
                  ])
            : null,
        focusedBorder: OutlineInputBorder(
            borderSide: BorderSide(color: AppTheme.primaryColorLight, width: 2),
            borderRadius: BorderRadius.circular(ScreenAdaper.sp(15))),
        hintText: widget.hint ?? '请输入',
      ),
    );
  }
}
